@@ -332,10 +332,11 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
     )
     uploader = manager.uploader('python')
     images = [i.get('imagename', '') for i in result]
-    if result:
-        default_tag = result[0].get('default_tag', False)
-    else:
-        default_tag = False
+    # set a flag to record whether the default tag is used or not. the
+    # logic here is that if the tag key is not already in mapping then it
+    # wil be added during the template render, so default_tag is set to
+    # True.
+    default_tag = 'tag' not in mapping_args
 
     if tag_from_label:
         image_version_tags = uploader.discover_image_tags(
@@ -453,11 +454,6 @@ class KollaImageBuilder(base.BaseImageManager):
         hyphenated appropriately.
         '''
         mapping = dict(kwargs)
-        # set a flag to record whether the default tag is used or not. the
-        # logic here is that if the tag key is not already in mapping then it
-        # wil be added during the template render, so default_tag is set to
-        # True.
-        mapping['default_tag'] = 'tag' not in mapping
 
         if CONTAINER_IMAGES_DEFAULTS is None:
             return
